GOTG FLUTTER PACKAGES MODELS - a unified flutter models for all Greggs Flutter Projects and Packages.
Features
Generic models and setups such as:
- API Config
- Extensions
- Helpers
- Article, Basket, Promotion, Scan, etc
Getting started
Add the latest version of the package into your pubspec.yaml. The current minimum Flutter Version is 3.3.0